@@ -9,12 +9,11 @@
 #' @name cubature-package
 #' @useDynLib cubature
 #' @aliases cubature-package cubature
-#' @docType package
 #' @author C code by Steven G. Johnson and Thomas Hahn, R by Balasubramanian Narasimhan, Manuel Koller, Simen Gaure, Kiên Kiêu, and Annie Bouvier
 #'
 #' Maintainer: Balasubramanian Narasimhan<naras@stat.stanford.edu>
-#' @keywords package
-NULL
+#' @keywords internal
+"_PACKAGE"
 
 
 
